diff --git a/gnu/packages/java.scm b/gnu/packages/java.scm
index 8c65d713f6..d22cb2600d 100644
--- a/gnu/packages/java.scm
+++ b/gnu/packages/java.scm
@@ -4335,7 +4335,7 @@ (define-public java-plexus-utils
 (define-public java-plexus-utils-3.2.1
   (package
     (inherit java-plexus-utils)
     ;; sisu-build-api needs this version, later versions don't work
     (version "3.2.1")
     (source (origin
               (method git-fetch)
@@ -5099,7 +5099,7 @@ (define-public java-plexus-sec-dispatcher
        ("java-plexus-utils" ,java-plexus-utils)
        ("java-guava" ,java-guava)
        ("java-geronimo-xbean-reflect" ,java-geronimo-xbean-reflect)
-       ("java-sisu-build-api" ,java-sisu-build-api)
+       ("java-plexus-build-api" ,java-plexus-build-api)
        ;; modello plugins:
        ("java-modellop-plugins-java" ,java-modello-plugins-java)
        ("java-modellop-plugins-xml" ,java-modello-plugins-xml)
@@ -5143,14 +5143,14 @@ (define-public java-plexus-cli
 Plexus components.")
     (license license:asl2.0)))
 
-(define-public java-sisu-build-api
+(define-public java-plexus-build-api
   (package
-    (name "java-sisu-build-api")
+    (name "java-plexus-build-api")
     (version "0.0.7")
     (source (origin
               (method git-fetch)
               (uri (git-reference
-                     (url "https://github.com/sonatype/sisu-build-api")
+                     (url "https://github.com/codehaus-plexus/plexus-build-api")
                      (commit (string-append "plexus-build-api-" version))))
               (file-name (git-file-name name version))
               (sha256
@@ -5158,7 +5158,7 @@ (define-public java-sisu-build-api
                 "1d5w6c58gkx30d51v7qwv1xrhc0ly76848gihmgshj19yf6yhca0"))))
     (build-system ant-build-system)
     (arguments
-     `(#:jar-name "sisu-build-api.jar"
+     `(#:jar-name "plexus-build-api.jar"
        #:source-dir "src/main/java"
        #:jdk ,icedtea-8
        #:tests? #f; FIXME: how to run the tests?
@@ -5194,7 +5194,7 @@ (define-public java-sisu-build-api
            (install-from-pom "pom.xml")))))
     (inputs
      (list java-plexus-utils-3.2.1 java-plexus-container-default))
-    (home-page "https://github.com/sonatype/sisu-build-api/")
+    (home-page "https://github.com/codehaus-plexus/plexus-build-api/")
     (synopsis "Base build API for maven")
     (description "This package contains the base build API for maven and
 a default implementation of it.  This API is about scanning files in a
@@ -5238,7 +5238,7 @@ (define-public java-modello-core
              #t)))))
     (propagated-inputs
      (list java-plexus-utils java-plexus-container-default
-           java-sisu-build-api))
+           java-plexus-build-api))
     (native-inputs
      (list java-junit java-plexus-classworlds java-geronimo-xbean-reflect
            java-guava))
@@ -4335,7 +4335,7 @@ (define-public java-plexus-utils
   (package
     (inherit java-plexus-utils)
-    ;; sisu-build-api needs this version, later versions don't work
+    ;; plexus-build-api needs this version, later versions don't work
     (version "3.2.1")
     (source (origin
diff --git a/gnu/packages/maven.scm b/gnu/packages/maven.scm
index 38b93f43b7..14cbf49482 100644
--- a/gnu/packages/maven.scm
+++ b/gnu/packages/maven.scm
@@ -1088,7 +1088,7 @@ (define-public maven-model
            java-plexus-classworlds
            java-guava
            java-geronimo-xbean-reflect
-           java-sisu-build-api
+           java-plexus-build-api
            ;; modello plugins:
            java-modello-plugins-java
            java-modello-plugins-xml
@@ -1166,7 +1166,7 @@ (define-public maven-settings
            java-plexus-utils
            java-guava
            java-geronimo-xbean-reflect
-           java-sisu-build-api
+           java-plexus-build-api
            ;; modello plugins:
            java-modello-plugins-java
            java-modello-plugins-xml
@@ -1302,7 +1302,7 @@ (define-public maven-repository-metadata
        ("java-plexus-classworlds" ,java-plexus-classworlds)
        ("java-guava" ,java-guava)
        ("java-geronimo-xbean-reflect" ,java-geronimo-xbean-reflect)
-       ("java-sisu-build-api" ,java-sisu-build-api)
+       ("java-plexus-build-api" ,java-plexus-build-api)
        ;; modello plugins:
        ("java-modello-plugins-java" ,java-modello-plugins-java)
        ("java-modello-plugins-xml" ,java-modello-plugins-xml)
@@ -1387,7 +1387,7 @@ (define-public maven-plugin-api
        ("classworlds" ,java-plexus-classworlds)
        ("guava" ,java-guava)
        ("xbean" ,java-geronimo-xbean-reflect)
-       ("build-api" ,java-sisu-build-api)
+       ("build-api" ,java-plexus-build-api)
        ;; modello plugins:
        ("java" ,java-modello-plugins-java)
        ("xml" ,java-modello-plugins-xml)
@@ -1491,7 +1491,7 @@ (define-public maven-core-bootstrap
          ("java-asm" ,java-asm)
          ("java-plexus-classworlds" ,java-plexus-classworlds)
          ("java-geronimo-xbean-reflect" ,java-geronimo-xbean-reflect)
-         ("java-sisu-build-api" ,java-sisu-build-api)
+         ("java-plexus-build-api" ,java-plexus-build-api)
          ("java-modello-plugins-java" ,java-modello-plugins-java)
          ("java-modello-plugins-xml" ,java-modello-plugins-xml)
          ("java-modello-plugins-xpp3" ,java-modello-plugins-xpp3)
@@ -1677,7 +1677,7 @@ (define-public maven-embedder
     (native-inputs
      `(("java-modello-core" ,java-modello-core)
        ("java-geronimo-xbean-reflect" ,java-geronimo-xbean-reflect)
-       ("java-sisu-build-api" ,java-sisu-build-api)
+       ("java-plexus-build-api" ,java-plexus-build-api)
        ("java-eclipse-sisu-plexus" ,java-eclipse-sisu-plexus)
        ("java-eclipse-sisu-inject" ,java-eclipse-sisu-inject)
        ("java-cglib" ,java-cglib)
@@ -1866,7 +1866,7 @@ (define-public maven-compat
        ("java-plexus-component-annotations" ,java-plexus-component-annotations)
        ("java-plexus-classworlds" ,java-plexus-classworlds)
        ("java-geronimo-xbean-reflect" ,java-geronimo-xbean-reflect)
-       ("java-sisu-build-api" ,java-sisu-build-api)
+       ("java-plexus-build-api" ,java-plexus-build-api)
        ("java-eclipse-sisu-plexus" ,java-eclipse-sisu-plexus)
        ("java-exclispe-sisu-inject" ,java-eclipse-sisu-inject)
        ("java-javax-inject" ,java-javax-inject)
@@ -2870,7 +2870,7 @@ (define-public maven-filtering
      `(#:jar-name "maven-filtering.jar"
        #:source-dir "src/main/java"
        #:test-dir "src/test"
        ;; this test comes from sisu-build-api, not this package
        #:test-exclude (list "**/IncrementalResourceFilteringTest.java"
                             "**/Abstract*.java")
        #:phases
@@ -2890,7 +2890,7 @@ (define-public maven-filtering
              #t))
          (add-before 'check 'decompress-tests
            (lambda* (#:key inputs #:allow-other-keys)
-             (let* ((build-api-source (assoc-ref inputs "java-sisu-build-api-origin"))
+             (let* ((build-api-source (assoc-ref inputs "java-plexus-build-api-origin"))
                     (classes (string-append build-api-source "/src/test/java")))
                (copy-recursively classes "src/test/"))
              #t))
@@ -2909,7 +2909,7 @@ (define-public maven-filtering
            maven-shared-utils
            java-plexus-utils-3.2.1
            java-plexus-interpolation
-           java-sisu-build-api
+           java-plexus-build-api
            maven-parent-pom-30))
     (inputs
      (list java-jsr305))
@@ -2920,7 +2920,7 @@ (define-public maven-filtering
        ("java-mockito" ,java-mockito-1)
        ("java-objenesis" ,java-objenesis)
        ("java-plexus-component-metadata" ,java-plexus-component-metadata)
-       ("java-sisu-build-api-origin" ,(package-source java-sisu-build-api))))
+       ("java-plexus-build-api-origin" ,(package-source java-plexus-build-api))))
     (home-page "https://maven.apache.org/shared/maven-filtering")
     (synopsis "Shared component for all plugins that needs to filter resources")
     (description "This component provides an API to filter resources in Maven
@@ -2870,7 +2870,7 @@ (define-public maven-filtering
        #:source-dir "src/main/java"
        #:test-dir "src/test"
-       ;; this test comes from sisu-build-api, not this package
+       ;; this test comes from plexus-build-api, not this package
        #:test-exclude (list "**/IncrementalResourceFilteringTest.java"
                             "**/Abstract*.java")
